==> haskell-src-exts-util-0.2.5-427.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-util
version:              0.2.5
visibility:           public
id:                   haskell-src-exts-util-0.2.5-DGalArgYU9YJG5ODRqEP82
key:                  haskell-src-exts-util-0.2.5-DGalArgYU9YJG5ODRqEP82
license:              BSD-3-Clause
copyright:            All Rights Reserved
maintainer:           pepeiborra@gmail.com
author:               Neil Mitchell, Jose Iborra
homepage:             https://github.com/pepeiborra/haskell-src-exts-util
synopsis:             Helper functions for working with haskell-src-exts trees
description:          Helper functions for working with haskell-src-exts trees.
category:             language
abi:                  832ca779944e446e47a3750fdcaa414f
exposed:              True
exposed-modules:      Language.Haskell.Exts.Util
hidden-modules:
    Language.Haskell.Exts.Bracket Language.Haskell.Exts.FreeVars
    Language.Haskell.Exts.Util.Internal Paths_haskell_src_exts_util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-util-0.2.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-util-0.2.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-util
hs-libraries:         HShaskell-src-exts-util-0.2.5-DGalArgYU9YJG5ODRqEP82
depends:
    base-4.18.2.1 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    haskell-src-exts-1.23.1-F3jL8MeOgpf1H3BDGTEVcV transformers-0.6.1.0
    uniplate-1.6.13-3WatGBC3kLsu5Mf9WJ1JN

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-util-0.2.5-428-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-src-exts-util
version:              0.2.5
visibility:           public
id:                   haskell-src-exts-util-0.2.5-A4T6MRtWP4S29YCa22ueOM
key:                  haskell-src-exts-util-0.2.5-A4T6MRtWP4S29YCa22ueOM
license:              BSD-3-Clause
copyright:            All Rights Reserved
maintainer:           pepeiborra@gmail.com
author:               Neil Mitchell, Jose Iborra
homepage:             https://github.com/pepeiborra/haskell-src-exts-util
synopsis:             Helper functions for working with haskell-src-exts trees
description:          Helper functions for working with haskell-src-exts trees.
category:             language
abi:                  982e321648ac1d5a17d17105f07e0007
exposed:              True
exposed-modules:      Language.Haskell.Exts.Util
hidden-modules:
    Language.Haskell.Exts.Bracket Language.Haskell.Exts.FreeVars
    Language.Haskell.Exts.Util.Internal Paths_haskell_src_exts_util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-util-0.2.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-util-0.2.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/haskell-src-exts-util-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-src-exts-util
hs-libraries:         HShaskell-src-exts-util-0.2.5-A4T6MRtWP4S29YCa22ueOM
depends:
    base-4.18.2.1 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    haskell-src-exts-1.23.1-63590nDmfj1880iQCS4JdS transformers-0.6.1.0
    uniplate-1.6.13-KGH5CSn0bIt6TRjVfDPPFU

haddock-interfaces:
    /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock

haddock-html:         /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
